@@ -1,5 +1,5 @@
 -- Test for #1617
 module T1617 where
 import Prelude ()
-import Control.Monad (mplus)
+--import Control.Monad (mplus)
 import qualified Control.Monad (mplus)
