@@ -44,206 +44,208 @@ module GenBigTypes where
 
   instance Generic BigSum where
     type Rep BigSum = Rep_BigSum
-    from C0 = M1 (L1 (L1 (L1 (L1 (L1 (L1 (M1 U1)))))))
-    from C1 = M1 (L1 (L1 (L1 (L1 (L1 (R1 (L1 (M1 U1))))))))
-    from C2 = M1 (L1 (L1 (L1 (L1 (L1 (R1 (R1 (M1 U1))))))))
-    from C3 = M1 (L1 (L1 (L1 (L1 (R1 (L1 (M1 U1)))))))
-    from C4 = M1 (L1 (L1 (L1 (L1 (R1 (R1 (L1 (M1 U1))))))))
-    from C5 = M1 (L1 (L1 (L1 (L1 (R1 (R1 (R1 (M1 U1))))))))
-    from C6 = M1 (L1 (L1 (L1 (R1 (L1 (L1 (M1 U1)))))))
-    from C7 = M1 (L1 (L1 (L1 (R1 (L1 (R1 (L1 (M1 U1))))))))
-    from C8 = M1 (L1 (L1 (L1 (R1 (L1 (R1 (R1 (M1 U1))))))))
-    from C9 = M1 (L1 (L1 (L1 (R1 (R1 (L1 (M1 U1)))))))
-    from C10 = M1 (L1 (L1 (L1 (R1 (R1 (R1 (L1 (M1 U1))))))))
-    from C11 = M1 (L1 (L1 (L1 (R1 (R1 (R1 (R1 (M1 U1))))))))
-    from C12 = M1 (L1 (L1 (R1 (L1 (L1 (L1 (M1 U1)))))))
-    from C13 = M1 (L1 (L1 (R1 (L1 (L1 (R1 (L1 (M1 U1))))))))
-    from C14 = M1 (L1 (L1 (R1 (L1 (L1 (R1 (R1 (M1 U1))))))))
-    from C15 = M1 (L1 (L1 (R1 (L1 (R1 (L1 (M1 U1)))))))
-    from C16 = M1 (L1 (L1 (R1 (L1 (R1 (R1 (L1 (M1 U1))))))))
-    from C17 = M1 (L1 (L1 (R1 (L1 (R1 (R1 (R1 (M1 U1))))))))
-    from C18 = M1 (L1 (L1 (R1 (R1 (L1 (L1 (M1 U1)))))))
-    from C19 = M1 (L1 (L1 (R1 (R1 (L1 (R1 (L1 (M1 U1))))))))
-    from C20 = M1 (L1 (L1 (R1 (R1 (L1 (R1 (R1 (M1 U1))))))))
-    from C21 = M1 (L1 (L1 (R1 (R1 (R1 (L1 (L1 (M1 U1))))))))
-    from C22 = M1 (L1 (L1 (R1 (R1 (R1 (L1 (R1 (M1 U1))))))))
-    from C23 = M1 (L1 (L1 (R1 (R1 (R1 (R1 (L1 (M1 U1))))))))
-    from C24 = M1 (L1 (L1 (R1 (R1 (R1 (R1 (R1 (M1 U1))))))))
-    from C25 = M1 (L1 (R1 (L1 (L1 (L1 (L1 (M1 U1)))))))
-    from C26 = M1 (L1 (R1 (L1 (L1 (L1 (R1 (L1 (M1 U1))))))))
-    from C27 = M1 (L1 (R1 (L1 (L1 (L1 (R1 (R1 (M1 U1))))))))
-    from C28 = M1 (L1 (R1 (L1 (L1 (R1 (L1 (M1 U1)))))))
-    from C29 = M1 (L1 (R1 (L1 (L1 (R1 (R1 (L1 (M1 U1))))))))
-    from C30 = M1 (L1 (R1 (L1 (L1 (R1 (R1 (R1 (M1 U1))))))))
-    from C31 = M1 (L1 (R1 (L1 (R1 (L1 (L1 (M1 U1)))))))
-    from C32 = M1 (L1 (R1 (L1 (R1 (L1 (R1 (L1 (M1 U1))))))))
-    from C33 = M1 (L1 (R1 (L1 (R1 (L1 (R1 (R1 (M1 U1))))))))
-    from C34 = M1 (L1 (R1 (L1 (R1 (R1 (L1 (M1 U1)))))))
-    from C35 = M1 (L1 (R1 (L1 (R1 (R1 (R1 (L1 (M1 U1))))))))
-    from C36 = M1 (L1 (R1 (L1 (R1 (R1 (R1 (R1 (M1 U1))))))))
-    from C37 = M1 (L1 (R1 (R1 (L1 (L1 (L1 (M1 U1)))))))
-    from C38 = M1 (L1 (R1 (R1 (L1 (L1 (R1 (L1 (M1 U1))))))))
-    from C39 = M1 (L1 (R1 (R1 (L1 (L1 (R1 (R1 (M1 U1))))))))
-    from C40 = M1 (L1 (R1 (R1 (L1 (R1 (L1 (M1 U1)))))))
-    from C41 = M1 (L1 (R1 (R1 (L1 (R1 (R1 (L1 (M1 U1))))))))
-    from C42 = M1 (L1 (R1 (R1 (L1 (R1 (R1 (R1 (M1 U1))))))))
-    from C43 = M1 (L1 (R1 (R1 (R1 (L1 (L1 (M1 U1)))))))
-    from C44 = M1 (L1 (R1 (R1 (R1 (L1 (R1 (L1 (M1 U1))))))))
-    from C45 = M1 (L1 (R1 (R1 (R1 (L1 (R1 (R1 (M1 U1))))))))
-    from C46 = M1 (L1 (R1 (R1 (R1 (R1 (L1 (L1 (M1 U1))))))))
-    from C47 = M1 (L1 (R1 (R1 (R1 (R1 (L1 (R1 (M1 U1))))))))
-    from C48 = M1 (L1 (R1 (R1 (R1 (R1 (R1 (L1 (M1 U1))))))))
-    from C49 = M1 (L1 (R1 (R1 (R1 (R1 (R1 (R1 (M1 U1))))))))
-    from C50 = M1 (R1 (L1 (L1 (L1 (L1 (L1 (M1 U1)))))))
-    from C51 = M1 (R1 (L1 (L1 (L1 (L1 (R1 (L1 (M1 U1))))))))
-    from C52 = M1 (R1 (L1 (L1 (L1 (L1 (R1 (R1 (M1 U1))))))))
-    from C53 = M1 (R1 (L1 (L1 (L1 (R1 (L1 (M1 U1)))))))
-    from C54 = M1 (R1 (L1 (L1 (L1 (R1 (R1 (L1 (M1 U1))))))))
-    from C55 = M1 (R1 (L1 (L1 (L1 (R1 (R1 (R1 (M1 U1))))))))
-    from C56 = M1 (R1 (L1 (L1 (R1 (L1 (L1 (M1 U1)))))))
-    from C57 = M1 (R1 (L1 (L1 (R1 (L1 (R1 (L1 (M1 U1))))))))
-    from C58 = M1 (R1 (L1 (L1 (R1 (L1 (R1 (R1 (M1 U1))))))))
-    from C59 = M1 (R1 (L1 (L1 (R1 (R1 (L1 (M1 U1)))))))
-    from C60 = M1 (R1 (L1 (L1 (R1 (R1 (R1 (L1 (M1 U1))))))))
-    from C61 = M1 (R1 (L1 (L1 (R1 (R1 (R1 (R1 (M1 U1))))))))
-    from C62 = M1 (R1 (L1 (R1 (L1 (L1 (L1 (M1 U1)))))))
-    from C63 = M1 (R1 (L1 (R1 (L1 (L1 (R1 (L1 (M1 U1))))))))
-    from C64 = M1 (R1 (L1 (R1 (L1 (L1 (R1 (R1 (M1 U1))))))))
-    from C65 = M1 (R1 (L1 (R1 (L1 (R1 (L1 (M1 U1)))))))
-    from C66 = M1 (R1 (L1 (R1 (L1 (R1 (R1 (L1 (M1 U1))))))))
-    from C67 = M1 (R1 (L1 (R1 (L1 (R1 (R1 (R1 (M1 U1))))))))
-    from C68 = M1 (R1 (L1 (R1 (R1 (L1 (L1 (M1 U1)))))))
-    from C69 = M1 (R1 (L1 (R1 (R1 (L1 (R1 (L1 (M1 U1))))))))
-    from C70 = M1 (R1 (L1 (R1 (R1 (L1 (R1 (R1 (M1 U1))))))))
-    from C71 = M1 (R1 (L1 (R1 (R1 (R1 (L1 (L1 (M1 U1))))))))
-    from C72 = M1 (R1 (L1 (R1 (R1 (R1 (L1 (R1 (M1 U1))))))))
-    from C73 = M1 (R1 (L1 (R1 (R1 (R1 (R1 (L1 (M1 U1))))))))
-    from C74 = M1 (R1 (L1 (R1 (R1 (R1 (R1 (R1 (M1 U1))))))))
-    from C75 = M1 (R1 (R1 (L1 (L1 (L1 (L1 (M1 U1)))))))
-    from C76 = M1 (R1 (R1 (L1 (L1 (L1 (R1 (L1 (M1 U1))))))))
-    from C77 = M1 (R1 (R1 (L1 (L1 (L1 (R1 (R1 (M1 U1))))))))
-    from C78 = M1 (R1 (R1 (L1 (L1 (R1 (L1 (M1 U1)))))))
-    from C79 = M1 (R1 (R1 (L1 (L1 (R1 (R1 (L1 (M1 U1))))))))
-    from C80 = M1 (R1 (R1 (L1 (L1 (R1 (R1 (R1 (M1 U1))))))))
-    from C81 = M1 (R1 (R1 (L1 (R1 (L1 (L1 (M1 U1)))))))
-    from C82 = M1 (R1 (R1 (L1 (R1 (L1 (R1 (L1 (M1 U1))))))))
-    from C83 = M1 (R1 (R1 (L1 (R1 (L1 (R1 (R1 (M1 U1))))))))
-    from C84 = M1 (R1 (R1 (L1 (R1 (R1 (L1 (M1 U1)))))))
-    from C85 = M1 (R1 (R1 (L1 (R1 (R1 (R1 (L1 (M1 U1))))))))
-    from C86 = M1 (R1 (R1 (L1 (R1 (R1 (R1 (R1 (M1 U1))))))))
-    from C87 = M1 (R1 (R1 (R1 (L1 (L1 (L1 (M1 U1)))))))
-    from C88 = M1 (R1 (R1 (R1 (L1 (L1 (R1 (L1 (M1 U1))))))))
-    from C89 = M1 (R1 (R1 (R1 (L1 (L1 (R1 (R1 (M1 U1))))))))
-    from C90 = M1 (R1 (R1 (R1 (L1 (R1 (L1 (M1 U1)))))))
-    from C91 = M1 (R1 (R1 (R1 (L1 (R1 (R1 (L1 (M1 U1))))))))
-    from C92 = M1 (R1 (R1 (R1 (L1 (R1 (R1 (R1 (M1 U1))))))))
-    from C93 = M1 (R1 (R1 (R1 (R1 (L1 (L1 (M1 U1)))))))
-    from C94 = M1 (R1 (R1 (R1 (R1 (L1 (R1 (L1 (M1 U1))))))))
-    from C95 = M1 (R1 (R1 (R1 (R1 (L1 (R1 (R1 (M1 U1))))))))
-    from C96 = M1 (R1 (R1 (R1 (R1 (R1 (L1 (L1 (M1 U1))))))))
-    from C97 = M1 (R1 (R1 (R1 (R1 (R1 (L1 (R1 (M1 U1))))))))
-    from C98 = M1 (R1 (R1 (R1 (R1 (R1 (R1 (L1 (M1 U1))))))))
-    from C99 = M1 (R1 (R1 (R1 (R1 (R1 (R1 (R1 (M1 U1))))))))
-    to (M1 (L1 (L1 (L1 (L1 (L1 (L1 (M1 U1)))))))) = C0
-    to (M1 (L1 (L1 (L1 (L1 (L1 (R1 (L1 (M1 U1))))))))) = C1
-    to (M1 (L1 (L1 (L1 (L1 (L1 (R1 (R1 (M1 U1))))))))) = C2
-    to (M1 (L1 (L1 (L1 (L1 (R1 (L1 (M1 U1)))))))) = C3
-    to (M1 (L1 (L1 (L1 (L1 (R1 (R1 (L1 (M1 U1))))))))) = C4
-    to (M1 (L1 (L1 (L1 (L1 (R1 (R1 (R1 (M1 U1))))))))) = C5
-    to (M1 (L1 (L1 (L1 (R1 (L1 (L1 (M1 U1)))))))) = C6
-    to (M1 (L1 (L1 (L1 (R1 (L1 (R1 (L1 (M1 U1))))))))) = C7
-    to (M1 (L1 (L1 (L1 (R1 (L1 (R1 (R1 (M1 U1))))))))) = C8
-    to (M1 (L1 (L1 (L1 (R1 (R1 (L1 (M1 U1)))))))) = C9
-    to (M1 (L1 (L1 (L1 (R1 (R1 (R1 (L1 (M1 U1))))))))) = C10
-    to (M1 (L1 (L1 (L1 (R1 (R1 (R1 (R1 (M1 U1))))))))) = C11
-    to (M1 (L1 (L1 (R1 (L1 (L1 (L1 (M1 U1)))))))) = C12
-    to (M1 (L1 (L1 (R1 (L1 (L1 (R1 (L1 (M1 U1))))))))) = C13
-    to (M1 (L1 (L1 (R1 (L1 (L1 (R1 (R1 (M1 U1))))))))) = C14
-    to (M1 (L1 (L1 (R1 (L1 (R1 (L1 (M1 U1)))))))) = C15
-    to (M1 (L1 (L1 (R1 (L1 (R1 (R1 (L1 (M1 U1))))))))) = C16
-    to (M1 (L1 (L1 (R1 (L1 (R1 (R1 (R1 (M1 U1))))))))) = C17
-    to (M1 (L1 (L1 (R1 (R1 (L1 (L1 (M1 U1)))))))) = C18
-    to (M1 (L1 (L1 (R1 (R1 (L1 (R1 (L1 (M1 U1))))))))) = C19
-    to (M1 (L1 (L1 (R1 (R1 (L1 (R1 (R1 (M1 U1))))))))) = C20
-    to (M1 (L1 (L1 (R1 (R1 (R1 (L1 (L1 (M1 U1))))))))) = C21
-    to (M1 (L1 (L1 (R1 (R1 (R1 (L1 (R1 (M1 U1))))))))) = C22
-    to (M1 (L1 (L1 (R1 (R1 (R1 (R1 (L1 (M1 U1))))))))) = C23
-    to (M1 (L1 (L1 (R1 (R1 (R1 (R1 (R1 (M1 U1))))))))) = C24
-    to (M1 (L1 (R1 (L1 (L1 (L1 (L1 (M1 U1)))))))) = C25
-    to (M1 (L1 (R1 (L1 (L1 (L1 (R1 (L1 (M1 U1))))))))) = C26
-    to (M1 (L1 (R1 (L1 (L1 (L1 (R1 (R1 (M1 U1))))))))) = C27
-    to (M1 (L1 (R1 (L1 (L1 (R1 (L1 (M1 U1)))))))) = C28
-    to (M1 (L1 (R1 (L1 (L1 (R1 (R1 (L1 (M1 U1))))))))) = C29
-    to (M1 (L1 (R1 (L1 (L1 (R1 (R1 (R1 (M1 U1))))))))) = C30
-    to (M1 (L1 (R1 (L1 (R1 (L1 (L1 (M1 U1)))))))) = C31
-    to (M1 (L1 (R1 (L1 (R1 (L1 (R1 (L1 (M1 U1))))))))) = C32
-    to (M1 (L1 (R1 (L1 (R1 (L1 (R1 (R1 (M1 U1))))))))) = C33
-    to (M1 (L1 (R1 (L1 (R1 (R1 (L1 (M1 U1)))))))) = C34
-    to (M1 (L1 (R1 (L1 (R1 (R1 (R1 (L1 (M1 U1))))))))) = C35
-    to (M1 (L1 (R1 (L1 (R1 (R1 (R1 (R1 (M1 U1))))))))) = C36
-    to (M1 (L1 (R1 (R1 (L1 (L1 (L1 (M1 U1)))))))) = C37
-    to (M1 (L1 (R1 (R1 (L1 (L1 (R1 (L1 (M1 U1))))))))) = C38
-    to (M1 (L1 (R1 (R1 (L1 (L1 (R1 (R1 (M1 U1))))))))) = C39
-    to (M1 (L1 (R1 (R1 (L1 (R1 (L1 (M1 U1)))))))) = C40
-    to (M1 (L1 (R1 (R1 (L1 (R1 (R1 (L1 (M1 U1))))))))) = C41
-    to (M1 (L1 (R1 (R1 (L1 (R1 (R1 (R1 (M1 U1))))))))) = C42
-    to (M1 (L1 (R1 (R1 (R1 (L1 (L1 (M1 U1)))))))) = C43
-    to (M1 (L1 (R1 (R1 (R1 (L1 (R1 (L1 (M1 U1))))))))) = C44
-    to (M1 (L1 (R1 (R1 (R1 (L1 (R1 (R1 (M1 U1))))))))) = C45
-    to (M1 (L1 (R1 (R1 (R1 (R1 (L1 (L1 (M1 U1))))))))) = C46
-    to (M1 (L1 (R1 (R1 (R1 (R1 (L1 (R1 (M1 U1))))))))) = C47
-    to (M1 (L1 (R1 (R1 (R1 (R1 (R1 (L1 (M1 U1))))))))) = C48
-    to (M1 (L1 (R1 (R1 (R1 (R1 (R1 (R1 (M1 U1))))))))) = C49
-    to (M1 (R1 (L1 (L1 (L1 (L1 (L1 (M1 U1)))))))) = C50
-    to (M1 (R1 (L1 (L1 (L1 (L1 (R1 (L1 (M1 U1))))))))) = C51
-    to (M1 (R1 (L1 (L1 (L1 (L1 (R1 (R1 (M1 U1))))))))) = C52
-    to (M1 (R1 (L1 (L1 (L1 (R1 (L1 (M1 U1)))))))) = C53
-    to (M1 (R1 (L1 (L1 (L1 (R1 (R1 (L1 (M1 U1))))))))) = C54
-    to (M1 (R1 (L1 (L1 (L1 (R1 (R1 (R1 (M1 U1))))))))) = C55
-    to (M1 (R1 (L1 (L1 (R1 (L1 (L1 (M1 U1)))))))) = C56
-    to (M1 (R1 (L1 (L1 (R1 (L1 (R1 (L1 (M1 U1))))))))) = C57
-    to (M1 (R1 (L1 (L1 (R1 (L1 (R1 (R1 (M1 U1))))))))) = C58
-    to (M1 (R1 (L1 (L1 (R1 (R1 (L1 (M1 U1)))))))) = C59
-    to (M1 (R1 (L1 (L1 (R1 (R1 (R1 (L1 (M1 U1))))))))) = C60
-    to (M1 (R1 (L1 (L1 (R1 (R1 (R1 (R1 (M1 U1))))))))) = C61
-    to (M1 (R1 (L1 (R1 (L1 (L1 (L1 (M1 U1)))))))) = C62
-    to (M1 (R1 (L1 (R1 (L1 (L1 (R1 (L1 (M1 U1))))))))) = C63
-    to (M1 (R1 (L1 (R1 (L1 (L1 (R1 (R1 (M1 U1))))))))) = C64
-    to (M1 (R1 (L1 (R1 (L1 (R1 (L1 (M1 U1)))))))) = C65
-    to (M1 (R1 (L1 (R1 (L1 (R1 (R1 (L1 (M1 U1))))))))) = C66
-    to (M1 (R1 (L1 (R1 (L1 (R1 (R1 (R1 (M1 U1))))))))) = C67
-    to (M1 (R1 (L1 (R1 (R1 (L1 (L1 (M1 U1)))))))) = C68
-    to (M1 (R1 (L1 (R1 (R1 (L1 (R1 (L1 (M1 U1))))))))) = C69
-    to (M1 (R1 (L1 (R1 (R1 (L1 (R1 (R1 (M1 U1))))))))) = C70
-    to (M1 (R1 (L1 (R1 (R1 (R1 (L1 (L1 (M1 U1))))))))) = C71
-    to (M1 (R1 (L1 (R1 (R1 (R1 (L1 (R1 (M1 U1))))))))) = C72
-    to (M1 (R1 (L1 (R1 (R1 (R1 (R1 (L1 (M1 U1))))))))) = C73
-    to (M1 (R1 (L1 (R1 (R1 (R1 (R1 (R1 (M1 U1))))))))) = C74
-    to (M1 (R1 (R1 (L1 (L1 (L1 (L1 (M1 U1)))))))) = C75
-    to (M1 (R1 (R1 (L1 (L1 (L1 (R1 (L1 (M1 U1))))))))) = C76
-    to (M1 (R1 (R1 (L1 (L1 (L1 (R1 (R1 (M1 U1))))))))) = C77
-    to (M1 (R1 (R1 (L1 (L1 (R1 (L1 (M1 U1)))))))) = C78
-    to (M1 (R1 (R1 (L1 (L1 (R1 (R1 (L1 (M1 U1))))))))) = C79
-    to (M1 (R1 (R1 (L1 (L1 (R1 (R1 (R1 (M1 U1))))))))) = C80
-    to (M1 (R1 (R1 (L1 (R1 (L1 (L1 (M1 U1)))))))) = C81
-    to (M1 (R1 (R1 (L1 (R1 (L1 (R1 (L1 (M1 U1))))))))) = C82
-    to (M1 (R1 (R1 (L1 (R1 (L1 (R1 (R1 (M1 U1))))))))) = C83
-    to (M1 (R1 (R1 (L1 (R1 (R1 (L1 (M1 U1)))))))) = C84
-    to (M1 (R1 (R1 (L1 (R1 (R1 (R1 (L1 (M1 U1))))))))) = C85
-    to (M1 (R1 (R1 (L1 (R1 (R1 (R1 (R1 (M1 U1))))))))) = C86
-    to (M1 (R1 (R1 (R1 (L1 (L1 (L1 (M1 U1)))))))) = C87
-    to (M1 (R1 (R1 (R1 (L1 (L1 (R1 (L1 (M1 U1))))))))) = C88
-    to (M1 (R1 (R1 (R1 (L1 (L1 (R1 (R1 (M1 U1))))))))) = C89
-    to (M1 (R1 (R1 (R1 (L1 (R1 (L1 (M1 U1)))))))) = C90
-    to (M1 (R1 (R1 (R1 (L1 (R1 (R1 (L1 (M1 U1))))))))) = C91
-    to (M1 (R1 (R1 (R1 (L1 (R1 (R1 (R1 (M1 U1))))))))) = C92
-    to (M1 (R1 (R1 (R1 (R1 (L1 (L1 (M1 U1)))))))) = C93
-    to (M1 (R1 (R1 (R1 (R1 (L1 (R1 (L1 (M1 U1))))))))) = C94
-    to (M1 (R1 (R1 (R1 (R1 (L1 (R1 (R1 (M1 U1))))))))) = C95
-    to (M1 (R1 (R1 (R1 (R1 (R1 (L1 (L1 (M1 U1))))))))) = C96
-    to (M1 (R1 (R1 (R1 (R1 (R1 (L1 (R1 (M1 U1))))))))) = C97
-    to (M1 (R1 (R1 (R1 (R1 (R1 (R1 (L1 (M1 U1))))))))) = C98
-    to (M1 (R1 (R1 (R1 (R1 (R1 (R1 (R1 (M1 U1))))))))) = C99
+    from x = M1 (case x of
+      C0  -> L1 (L1 (L1 (L1 (L1 (L1 (M1 U1))))))
+      C1  -> L1 (L1 (L1 (L1 (L1 (R1 (L1 (M1 U1)))))))
+      C2  -> L1 (L1 (L1 (L1 (L1 (R1 (R1 (M1 U1)))))))
+      C3  -> L1 (L1 (L1 (L1 (R1 (L1 (M1 U1))))))
+      C4  -> L1 (L1 (L1 (L1 (R1 (R1 (L1 (M1 U1)))))))
+      C5  -> L1 (L1 (L1 (L1 (R1 (R1 (R1 (M1 U1)))))))
+      C6  -> L1 (L1 (L1 (R1 (L1 (L1 (M1 U1))))))
+      C7  -> L1 (L1 (L1 (R1 (L1 (R1 (L1 (M1 U1)))))))
+      C8  -> L1 (L1 (L1 (R1 (L1 (R1 (R1 (M1 U1)))))))
+      C9  -> L1 (L1 (L1 (R1 (R1 (L1 (M1 U1))))))
+      C10 -> L1 (L1 (L1 (R1 (R1 (R1 (L1 (M1 U1)))))))
+      C11 -> L1 (L1 (L1 (R1 (R1 (R1 (R1 (M1 U1)))))))
+      C12 -> L1 (L1 (R1 (L1 (L1 (L1 (M1 U1))))))
+      C13 -> L1 (L1 (R1 (L1 (L1 (R1 (L1 (M1 U1)))))))
+      C14 -> L1 (L1 (R1 (L1 (L1 (R1 (R1 (M1 U1)))))))
+      C15 -> L1 (L1 (R1 (L1 (R1 (L1 (M1 U1))))))
+      C16 -> L1 (L1 (R1 (L1 (R1 (R1 (L1 (M1 U1)))))))
+      C17 -> L1 (L1 (R1 (L1 (R1 (R1 (R1 (M1 U1)))))))
+      C18 -> L1 (L1 (R1 (R1 (L1 (L1 (M1 U1))))))
+      C19 -> L1 (L1 (R1 (R1 (L1 (R1 (L1 (M1 U1)))))))
+      C20 -> L1 (L1 (R1 (R1 (L1 (R1 (R1 (M1 U1)))))))
+      C21 -> L1 (L1 (R1 (R1 (R1 (L1 (L1 (M1 U1)))))))
+      C22 -> L1 (L1 (R1 (R1 (R1 (L1 (R1 (M1 U1)))))))
+      C23 -> L1 (L1 (R1 (R1 (R1 (R1 (L1 (M1 U1)))))))
+      C24 -> L1 (L1 (R1 (R1 (R1 (R1 (R1 (M1 U1)))))))
+      C25 -> L1 (R1 (L1 (L1 (L1 (L1 (M1 U1))))))
+      C26 -> L1 (R1 (L1 (L1 (L1 (R1 (L1 (M1 U1)))))))
+      C27 -> L1 (R1 (L1 (L1 (L1 (R1 (R1 (M1 U1)))))))
+      C28 -> L1 (R1 (L1 (L1 (R1 (L1 (M1 U1))))))
+      C29 -> L1 (R1 (L1 (L1 (R1 (R1 (L1 (M1 U1)))))))
+      C30 -> L1 (R1 (L1 (L1 (R1 (R1 (R1 (M1 U1)))))))
+      C31 -> L1 (R1 (L1 (R1 (L1 (L1 (M1 U1))))))
+      C32 -> L1 (R1 (L1 (R1 (L1 (R1 (L1 (M1 U1)))))))
+      C33 -> L1 (R1 (L1 (R1 (L1 (R1 (R1 (M1 U1)))))))
+      C34 -> L1 (R1 (L1 (R1 (R1 (L1 (M1 U1))))))
+      C35 -> L1 (R1 (L1 (R1 (R1 (R1 (L1 (M1 U1)))))))
+      C36 -> L1 (R1 (L1 (R1 (R1 (R1 (R1 (M1 U1)))))))
+      C37 -> L1 (R1 (R1 (L1 (L1 (L1 (M1 U1))))))
+      C38 -> L1 (R1 (R1 (L1 (L1 (R1 (L1 (M1 U1)))))))
+      C39 -> L1 (R1 (R1 (L1 (L1 (R1 (R1 (M1 U1)))))))
+      C40 -> L1 (R1 (R1 (L1 (R1 (L1 (M1 U1))))))
+      C41 -> L1 (R1 (R1 (L1 (R1 (R1 (L1 (M1 U1)))))))
+      C42 -> L1 (R1 (R1 (L1 (R1 (R1 (R1 (M1 U1)))))))
+      C43 -> L1 (R1 (R1 (R1 (L1 (L1 (M1 U1))))))
+      C44 -> L1 (R1 (R1 (R1 (L1 (R1 (L1 (M1 U1)))))))
+      C45 -> L1 (R1 (R1 (R1 (L1 (R1 (R1 (M1 U1)))))))
+      C46 -> L1 (R1 (R1 (R1 (R1 (L1 (L1 (M1 U1)))))))
+      C47 -> L1 (R1 (R1 (R1 (R1 (L1 (R1 (M1 U1)))))))
+      C48 -> L1 (R1 (R1 (R1 (R1 (R1 (L1 (M1 U1)))))))
+      C49 -> L1 (R1 (R1 (R1 (R1 (R1 (R1 (M1 U1)))))))
+      C50 -> R1 (L1 (L1 (L1 (L1 (L1 (M1 U1))))))
+      C51 -> R1 (L1 (L1 (L1 (L1 (R1 (L1 (M1 U1)))))))
+      C52 -> R1 (L1 (L1 (L1 (L1 (R1 (R1 (M1 U1)))))))
+      C53 -> R1 (L1 (L1 (L1 (R1 (L1 (M1 U1))))))
+      C54 -> R1 (L1 (L1 (L1 (R1 (R1 (L1 (M1 U1)))))))
+      C55 -> R1 (L1 (L1 (L1 (R1 (R1 (R1 (M1 U1)))))))
+      C56 -> R1 (L1 (L1 (R1 (L1 (L1 (M1 U1))))))
+      C57 -> R1 (L1 (L1 (R1 (L1 (R1 (L1 (M1 U1)))))))
+      C58 -> R1 (L1 (L1 (R1 (L1 (R1 (R1 (M1 U1)))))))
+      C59 -> R1 (L1 (L1 (R1 (R1 (L1 (M1 U1))))))
+      C60 -> R1 (L1 (L1 (R1 (R1 (R1 (L1 (M1 U1)))))))
+      C61 -> R1 (L1 (L1 (R1 (R1 (R1 (R1 (M1 U1)))))))
+      C62 -> R1 (L1 (R1 (L1 (L1 (L1 (M1 U1))))))
+      C63 -> R1 (L1 (R1 (L1 (L1 (R1 (L1 (M1 U1)))))))
+      C64 -> R1 (L1 (R1 (L1 (L1 (R1 (R1 (M1 U1)))))))
+      C65 -> R1 (L1 (R1 (L1 (R1 (L1 (M1 U1))))))
+      C66 -> R1 (L1 (R1 (L1 (R1 (R1 (L1 (M1 U1)))))))
+      C67 -> R1 (L1 (R1 (L1 (R1 (R1 (R1 (M1 U1)))))))
+      C68 -> R1 (L1 (R1 (R1 (L1 (L1 (M1 U1))))))
+      C69 -> R1 (L1 (R1 (R1 (L1 (R1 (L1 (M1 U1)))))))
+      C70 -> R1 (L1 (R1 (R1 (L1 (R1 (R1 (M1 U1)))))))
+      C71 -> R1 (L1 (R1 (R1 (R1 (L1 (L1 (M1 U1)))))))
+      C72 -> R1 (L1 (R1 (R1 (R1 (L1 (R1 (M1 U1)))))))
+      C73 -> R1 (L1 (R1 (R1 (R1 (R1 (L1 (M1 U1)))))))
+      C74 -> R1 (L1 (R1 (R1 (R1 (R1 (R1 (M1 U1)))))))
+      C75 -> R1 (R1 (L1 (L1 (L1 (L1 (M1 U1))))))
+      C76 -> R1 (R1 (L1 (L1 (L1 (R1 (L1 (M1 U1)))))))
+      C77 -> R1 (R1 (L1 (L1 (L1 (R1 (R1 (M1 U1)))))))
+      C78 -> R1 (R1 (L1 (L1 (R1 (L1 (M1 U1))))))
+      C79 -> R1 (R1 (L1 (L1 (R1 (R1 (L1 (M1 U1)))))))
+      C80 -> R1 (R1 (L1 (L1 (R1 (R1 (R1 (M1 U1)))))))
+      C81 -> R1 (R1 (L1 (R1 (L1 (L1 (M1 U1))))))
+      C82 -> R1 (R1 (L1 (R1 (L1 (R1 (L1 (M1 U1)))))))
+      C83 -> R1 (R1 (L1 (R1 (L1 (R1 (R1 (M1 U1)))))))
+      C84 -> R1 (R1 (L1 (R1 (R1 (L1 (M1 U1))))))
+      C85 -> R1 (R1 (L1 (R1 (R1 (R1 (L1 (M1 U1)))))))
+      C86 -> R1 (R1 (L1 (R1 (R1 (R1 (R1 (M1 U1)))))))
+      C87 -> R1 (R1 (R1 (L1 (L1 (L1 (M1 U1))))))
+      C88 -> R1 (R1 (R1 (L1 (L1 (R1 (L1 (M1 U1)))))))
+      C89 -> R1 (R1 (R1 (L1 (L1 (R1 (R1 (M1 U1)))))))
+      C90 -> R1 (R1 (R1 (L1 (R1 (L1 (M1 U1))))))
+      C91 -> R1 (R1 (R1 (L1 (R1 (R1 (L1 (M1 U1)))))))
+      C92 -> R1 (R1 (R1 (L1 (R1 (R1 (R1 (M1 U1)))))))
+      C93 -> R1 (R1 (R1 (R1 (L1 (L1 (M1 U1))))))
+      C94 -> R1 (R1 (R1 (R1 (L1 (R1 (L1 (M1 U1)))))))
+      C95 -> R1 (R1 (R1 (R1 (L1 (R1 (R1 (M1 U1)))))))
+      C96 -> R1 (R1 (R1 (R1 (R1 (L1 (L1 (M1 U1)))))))
+      C97 -> R1 (R1 (R1 (R1 (R1 (L1 (R1 (M1 U1)))))))
+      C98 -> R1 (R1 (R1 (R1 (R1 (R1 (L1 (M1 U1)))))))
+      C99 -> R1 (R1 (R1 (R1 (R1 (R1 (R1 (M1 U1))))))))
+    to (M1 x) = case x of
+      L1 (L1 (L1 (L1 (L1 (L1 (M1 U1)))))) -> C0
+      L1 (L1 (L1 (L1 (L1 (R1 (L1 (M1 U1))))))) -> C1
+      L1 (L1 (L1 (L1 (L1 (R1 (R1 (M1 U1))))))) -> C2
+      L1 (L1 (L1 (L1 (R1 (L1 (M1 U1)))))) -> C3
+      L1 (L1 (L1 (L1 (R1 (R1 (L1 (M1 U1))))))) -> C4
+      L1 (L1 (L1 (L1 (R1 (R1 (R1 (M1 U1))))))) -> C5
+      L1 (L1 (L1 (R1 (L1 (L1 (M1 U1)))))) -> C6
+      L1 (L1 (L1 (R1 (L1 (R1 (L1 (M1 U1))))))) -> C7
+      L1 (L1 (L1 (R1 (L1 (R1 (R1 (M1 U1))))))) -> C8
+      L1 (L1 (L1 (R1 (R1 (L1 (M1 U1)))))) -> C9
+      L1 (L1 (L1 (R1 (R1 (R1 (L1 (M1 U1))))))) -> C10
+      L1 (L1 (L1 (R1 (R1 (R1 (R1 (M1 U1))))))) -> C11
+      L1 (L1 (R1 (L1 (L1 (L1 (M1 U1)))))) -> C12
+      L1 (L1 (R1 (L1 (L1 (R1 (L1 (M1 U1))))))) -> C13
+      L1 (L1 (R1 (L1 (L1 (R1 (R1 (M1 U1))))))) -> C14
+      L1 (L1 (R1 (L1 (R1 (L1 (M1 U1)))))) -> C15
+      L1 (L1 (R1 (L1 (R1 (R1 (L1 (M1 U1))))))) -> C16
+      L1 (L1 (R1 (L1 (R1 (R1 (R1 (M1 U1))))))) -> C17
+      L1 (L1 (R1 (R1 (L1 (L1 (M1 U1)))))) -> C18
+      L1 (L1 (R1 (R1 (L1 (R1 (L1 (M1 U1))))))) -> C19
+      L1 (L1 (R1 (R1 (L1 (R1 (R1 (M1 U1))))))) -> C20
+      L1 (L1 (R1 (R1 (R1 (L1 (L1 (M1 U1))))))) -> C21
+      L1 (L1 (R1 (R1 (R1 (L1 (R1 (M1 U1))))))) -> C22
+      L1 (L1 (R1 (R1 (R1 (R1 (L1 (M1 U1))))))) -> C23
+      L1 (L1 (R1 (R1 (R1 (R1 (R1 (M1 U1))))))) -> C24
+      L1 (R1 (L1 (L1 (L1 (L1 (M1 U1)))))) -> C25
+      L1 (R1 (L1 (L1 (L1 (R1 (L1 (M1 U1))))))) -> C26
+      L1 (R1 (L1 (L1 (L1 (R1 (R1 (M1 U1))))))) -> C27
+      L1 (R1 (L1 (L1 (R1 (L1 (M1 U1)))))) -> C28
+      L1 (R1 (L1 (L1 (R1 (R1 (L1 (M1 U1))))))) -> C29
+      L1 (R1 (L1 (L1 (R1 (R1 (R1 (M1 U1))))))) -> C30
+      L1 (R1 (L1 (R1 (L1 (L1 (M1 U1)))))) -> C31
+      L1 (R1 (L1 (R1 (L1 (R1 (L1 (M1 U1))))))) -> C32
+      L1 (R1 (L1 (R1 (L1 (R1 (R1 (M1 U1))))))) -> C33
+      L1 (R1 (L1 (R1 (R1 (L1 (M1 U1)))))) -> C34
+      L1 (R1 (L1 (R1 (R1 (R1 (L1 (M1 U1))))))) -> C35
+      L1 (R1 (L1 (R1 (R1 (R1 (R1 (M1 U1))))))) -> C36
+      L1 (R1 (R1 (L1 (L1 (L1 (M1 U1)))))) -> C37
+      L1 (R1 (R1 (L1 (L1 (R1 (L1 (M1 U1))))))) -> C38
+      L1 (R1 (R1 (L1 (L1 (R1 (R1 (M1 U1))))))) -> C39
+      L1 (R1 (R1 (L1 (R1 (L1 (M1 U1)))))) -> C40
+      L1 (R1 (R1 (L1 (R1 (R1 (L1 (M1 U1))))))) -> C41
+      L1 (R1 (R1 (L1 (R1 (R1 (R1 (M1 U1))))))) -> C42
+      L1 (R1 (R1 (R1 (L1 (L1 (M1 U1)))))) -> C43
+      L1 (R1 (R1 (R1 (L1 (R1 (L1 (M1 U1))))))) -> C44
+      L1 (R1 (R1 (R1 (L1 (R1 (R1 (M1 U1))))))) -> C45
+      L1 (R1 (R1 (R1 (R1 (L1 (L1 (M1 U1))))))) -> C46
+      L1 (R1 (R1 (R1 (R1 (L1 (R1 (M1 U1))))))) -> C47
+      L1 (R1 (R1 (R1 (R1 (R1 (L1 (M1 U1))))))) -> C48
+      L1 (R1 (R1 (R1 (R1 (R1 (R1 (M1 U1))))))) -> C49
+      R1 (L1 (L1 (L1 (L1 (L1 (M1 U1)))))) -> C50
+      R1 (L1 (L1 (L1 (L1 (R1 (L1 (M1 U1))))))) -> C51
+      R1 (L1 (L1 (L1 (L1 (R1 (R1 (M1 U1))))))) -> C52
+      R1 (L1 (L1 (L1 (R1 (L1 (M1 U1)))))) -> C53
+      R1 (L1 (L1 (L1 (R1 (R1 (L1 (M1 U1))))))) -> C54
+      R1 (L1 (L1 (L1 (R1 (R1 (R1 (M1 U1))))))) -> C55
+      R1 (L1 (L1 (R1 (L1 (L1 (M1 U1)))))) -> C56
+      R1 (L1 (L1 (R1 (L1 (R1 (L1 (M1 U1))))))) -> C57
+      R1 (L1 (L1 (R1 (L1 (R1 (R1 (M1 U1))))))) -> C58
+      R1 (L1 (L1 (R1 (R1 (L1 (M1 U1)))))) -> C59
+      R1 (L1 (L1 (R1 (R1 (R1 (L1 (M1 U1))))))) -> C60
+      R1 (L1 (L1 (R1 (R1 (R1 (R1 (M1 U1))))))) -> C61
+      R1 (L1 (R1 (L1 (L1 (L1 (M1 U1)))))) -> C62
+      R1 (L1 (R1 (L1 (L1 (R1 (L1 (M1 U1))))))) -> C63
+      R1 (L1 (R1 (L1 (L1 (R1 (R1 (M1 U1))))))) -> C64
+      R1 (L1 (R1 (L1 (R1 (L1 (M1 U1)))))) -> C65
+      R1 (L1 (R1 (L1 (R1 (R1 (L1 (M1 U1))))))) -> C66
+      R1 (L1 (R1 (L1 (R1 (R1 (R1 (M1 U1))))))) -> C67
+      R1 (L1 (R1 (R1 (L1 (L1 (M1 U1)))))) -> C68
+      R1 (L1 (R1 (R1 (L1 (R1 (L1 (M1 U1))))))) -> C69
+      R1 (L1 (R1 (R1 (L1 (R1 (R1 (M1 U1))))))) -> C70
+      R1 (L1 (R1 (R1 (R1 (L1 (L1 (M1 U1))))))) -> C71
+      R1 (L1 (R1 (R1 (R1 (L1 (R1 (M1 U1))))))) -> C72
+      R1 (L1 (R1 (R1 (R1 (R1 (L1 (M1 U1))))))) -> C73
+      R1 (L1 (R1 (R1 (R1 (R1 (R1 (M1 U1))))))) -> C74
+      R1 (R1 (L1 (L1 (L1 (L1 (M1 U1)))))) -> C75
+      R1 (R1 (L1 (L1 (L1 (R1 (L1 (M1 U1))))))) -> C76
+      R1 (R1 (L1 (L1 (L1 (R1 (R1 (M1 U1))))))) -> C77
+      R1 (R1 (L1 (L1 (R1 (L1 (M1 U1)))))) -> C78
+      R1 (R1 (L1 (L1 (R1 (R1 (L1 (M1 U1))))))) -> C79
+      R1 (R1 (L1 (L1 (R1 (R1 (R1 (M1 U1))))))) -> C80
+      R1 (R1 (L1 (R1 (L1 (L1 (M1 U1)))))) -> C81
+      R1 (R1 (L1 (R1 (L1 (R1 (L1 (M1 U1))))))) -> C82
+      R1 (R1 (L1 (R1 (L1 (R1 (R1 (M1 U1))))))) -> C83
+      R1 (R1 (L1 (R1 (R1 (L1 (M1 U1)))))) -> C84
+      R1 (R1 (L1 (R1 (R1 (R1 (L1 (M1 U1))))))) -> C85
+      R1 (R1 (L1 (R1 (R1 (R1 (R1 (M1 U1))))))) -> C86
+      R1 (R1 (R1 (L1 (L1 (L1 (M1 U1)))))) -> C87
+      R1 (R1 (R1 (L1 (L1 (R1 (L1 (M1 U1))))))) -> C88
+      R1 (R1 (R1 (L1 (L1 (R1 (R1 (M1 U1))))))) -> C89
+      R1 (R1 (R1 (L1 (R1 (L1 (M1 U1)))))) -> C90
+      R1 (R1 (R1 (L1 (R1 (R1 (L1 (M1 U1))))))) -> C91
+      R1 (R1 (R1 (L1 (R1 (R1 (R1 (M1 U1))))))) -> C92
+      R1 (R1 (R1 (R1 (L1 (L1 (M1 U1)))))) -> C93
+      R1 (R1 (R1 (R1 (L1 (R1 (L1 (M1 U1))))))) -> C94
+      R1 (R1 (R1 (R1 (L1 (R1 (R1 (M1 U1))))))) -> C95
+      R1 (R1 (R1 (R1 (R1 (L1 (L1 (M1 U1))))))) -> C96
+      R1 (R1 (R1 (R1 (R1 (L1 (R1 (M1 U1))))))) -> C97
+      R1 (R1 (R1 (R1 (R1 (R1 (L1 (M1 U1))))))) -> C98
+      R1 (R1 (R1 (R1 (R1 (R1 (R1 (M1 U1))))))) -> C99
 
   type Rep_BigSum = D1
                                        ('MetaData
