@@ -1,8 +1,9 @@
+{-# OPTIONS_GHC -fno-warn-redundant-constraints #-}
 {-# LANGUAGE RankNTypes #-}
 
 module ShouldSucceed where
 
-data Empty q			=  Empty (Ord a => q a)
+data Empty q			=  Empty (forall a. Ord a => q a)
 q				:: (Ord a) => [a]
 q				=  []
 e0, e1, e2			:: Empty []
